@@ -20,6 +20,8 @@ from ._nexus_loader import (
     load_all_components,
     load_component,
     load_data,
+    open_component_group,
+    open_nexus_file,
 )
 from .workflow import GenericNeXusWorkflow
 
@@ -31,5 +33,7 @@ __all__ = [
     'load_all_components',
     'load_component',
     'load_data',
+    'open_component_group',
+    'open_nexus_file',
     'types',
 ]
